@@ -2,7 +2,7 @@ package cmd
 
 import (
 	"bytes"
-	"io/ioutil"
+	"io"
 	"strings"
 	"testing"
 )
@@ -16,12 +16,12 @@ func TestVersionCmd(t *testing.T) {
 		t.Fatal(err)
 	}
 
-	out, err := ioutil.ReadAll(b)
+	out, err := io.ReadAll(b)
 	if err != nil {
 		t.Fatal(err)
 	}
 
-	if !strings.Contains(string(out), "v0.16.1") {
-		t.Fatalf("expected \"%s\" got \"%s\"", "v0.16.1", string(out))
+	if !strings.Contains(string(out), "v0.16.2") {
+		t.Fatalf("expected \"%s\" got \"%s\"", "v0.16.2", string(out))
 	}
 }
