@@ -98,10 +98,15 @@ func (c *Client) Query(q string, args ...interface{}) ([][]string, []string, err
 
 // Table represents a SQL table.
 type Table struct {
+	name    string
 	Rows    [][]string
 	Columns []string
 }
 
+func (t *Table) Name() string {
+	return t.name
+}
+
 // Metadata sums up the most relevant data from a table.
 type Metadata struct {
 	TableContent Table
@@ -170,6 +175,14 @@ func (c *Client) Metadata(tableName string) (*Metadata, error) {
 	return &m, nil
 }
 
+func (c *Client) TotalPages() int {
+	if c.paginationManager != nil {
+		return c.paginationManager.TotalPages()
+	}
+
+	return 0
+}
+
 // ShowTables list all the tables in the database on the tables panel.
 func (c *Client) ShowTables() ([]string, error) {
 	var query string
@@ -230,6 +243,7 @@ func (c *Client) NextPage() (*Table, int, error) {
 	}
 
 	t := Table{
+		name:    c.paginationManager.CurrentTable(),
 		Rows:    r,
 		Columns: col,
 	}
@@ -251,6 +265,7 @@ func (c *Client) PreviousPage() (*Table, int, error) {
 	}
 
 	t := Table{
+		name:    c.paginationManager.CurrentTable(),
 		Rows:    r,
 		Columns: col,
 	}
